# Empirical Utitlites

This package include empircal methods funcitons including OLS and a matrix solver. The utilites module contains functions which cleanly print results to the console for easy interpretation and prints data structures into LaTeX formatting for easy conversion to reports.

----
